/**
 * The class for managing your simple AWS CDK pipeline
 *
 * The class requires some properties described in the constructor comment.
 *
 * The class deploys all AWS resources for your pipeline:
 *
 *   AWS::IAM::Role with your policies
 *   AWS::S3::Bucket for your artifacts
 *   AWS::CodeBuild::Project that it loads your buildspec.yml on LinuxBuildImage.STANDARD_4_0
 *   AWS::CodePipeline::Webhook for triggering your pipeline to start every time github-push occurs
 *   AWS::CodePipeline::Pipeline with the stages named Source, Staging, Manual Approval and Production
 *
 * **license**: MIT,
 * **support**: https://github.com/bilardi/aws-simple-ts-pipeline/issues
 */
import * as cdk from "@aws-cdk/core";
export declare class PipelineStack extends cdk.Stack {
    /**
     * All properties are mandatory, except the last two params: buildspecPath and manualApprovalExists.
     *
     * @param id string of the name of project used for the prefix of the stack name
     * @param stage string of the name of the environment, default is empty
     * @param githubOwner string of the github owner
     * @param githubRepo string of the github repository name
     * @param githubBranch string of the github repository branch
     * @param githubToken AWS SecretValue object with reference like Secrets Manager
     * @param notifyEmails array of strings of emails to notify
     * @param policies array of strings of policies name to add
     * @param buildspecPath string of path of buildspec file, default: buildspec.yml
     * @param manualApprovalExists boolean if true, then there will be a manual approval stage; default: false
     */
    constructor(scope: cdk.Construct, id: string, stage: string | undefined, githubOwner: string, githubRepo: string, githubBranch: string, githubToken: cdk.SecretValue, notifyEmails: Array<string>, policies: Array<string>, buildspecPath?: string, manualApprovalExists?: boolean, props?: cdk.StackProps);
}
